@@ -50,6 +50,15 @@ function overrideSmConfig() {
   compatibility_sqsession_is_active();
 
 
+  // try to find username
+  //
+  $user = '';
+  if (isset($_SESSION['username']))
+     $user = $_SESSION['username'];
+  elseif (isset($_POST['login_username']))
+     $user = $_POST['login_username'];
+
+
   include_once (SM_PATH . 'plugins/vlogin/data/config.php');
 
 
@@ -99,11 +108,16 @@ function overrideSmConfig() {
   // override data_dir if the $virtualDomainDataDir variable 
   // has been specified
   //
-  if (!empty($virtualDomainDataDir)) {
+  if (!empty($virtualDomainDataDir)) 
+  {
      $the_data_dir = $virtualDomainDataDir;
      $the_data_dir = str_replace('###VIRTUAL_DOMAIN###', 
                              $hostname_stripped, 
                              $the_data_dir);
+     if (!empty($user))
+        $the_data_dir = str_replace('###USERNAME###', 
+                                $user, 
+                                $the_data_dir);
      if ($useSessionBased)
         $config_override['data_dir'] = $the_data_dir;
      else
@@ -148,7 +162,22 @@ function overrideSmConfig() {
       foreach ($virtualDomains[$virtualDomain] as $setting => $value)
       {
 
-        // Go ahead and replace the string ###VIRTUAL_DOMAIN###
+        // go ahead and replace the strings ###VIRTUAL_DOMAIN### and ###USERNAME###
+        //
+        if (!is_array($value))
+        {
+           if (strpos($value, '###VIRTUAL_DOMAIN###') !== FALSE)
+              $value = str_replace('###VIRTUAL_DOMAIN###',
+                                   $hostname_stripped,
+                                   $value);
+
+           if (strpos($value, '###USERNAME###') !== FALSE && !empty($user))
+              $value = str_replace('###USERNAME###', 
+                               $user, 
+                               $the_data_dir);
+        }
+         
+        // Go ahead and replace the string ###USERNAME###
         //
         if (!is_array($value))
            if (strpos($value, '###VIRTUAL_DOMAIN###') !== FALSE)
@@ -283,11 +312,6 @@ function overrideSmConfig() {
   // override settings on a per-user basis
 // TODO: not clear if this will work with password_forget and/or login_alias...
   //
-  $user = '';
-  if (isset($_SESSION['username']))
-     $user = $_SESSION['username'];
-  elseif (isset($_POST['login_username']))
-     $user = $_POST['login_username'];
   perUserOverride($user);
 
 
@@ -547,7 +571,7 @@ a user who was asking the impossible.  This just here for posterity...
      echo $realname;
      echo '</h4><br><hr>';
      // was confusing to people using $dontUseHostName 
-     // echo '<br>$hostname is ' . $hostname . '<br>';
+     if (!$dontUseHostName) echo '<br>$hostname is ' . $hostname . '<br>';
      echo '<br>PHP_SELF is ' . $_SERVER['PHP_SELF'] . '<br>';
 global        $imapServerAddress;
 echo '<hr>' . $imapServerAddress . '<hr>';
@@ -1094,4 +1118,56 @@ function getSendmailVirtualUser($user, $sendmailVirtualUserTable)
 
 
 
+/**
+  * Allows control over which options are displayed on options pages
+  *
+  */
+function vlogin_display_options_do()
+{
+
+   global $config_override, $optpage_data;
+
+   $overrides = array();
+
+
+   // try to get configuration settings from session, if they're there
+   //
+   if (!isset($config_override))
+   {
+
+      global $virtualDomains, $useSessionBased;
+      include_once (SM_PATH . 'plugins/vlogin/data/config.php');
+
+      if (!$useSessionBased)
+      {
+
+         // allow inclusion of external configuration files for each domain
+         //
+         if (file_exists(SM_PATH . 'plugins/vlogin/data/domains/' . $hostname_stripped . '.vlogin.config.php'))
+            include_once(SM_PATH . 'plugins/vlogin/data/domains/' . $hostname_stripped . '.vlogin.config.php');
+
+         if (is_array($virtualDomains))
+            $overrides = $virtualDomains;
+
+      }
+
+   }
+   else
+      $overrides = $config_override;
+
+
+
+   // remove any options from list of options as desired
+   //
+   if (isset($overrides['disable_options']) && is_array($overrides['disable_options']))
+      foreach ($overrides['disable_options'] as $removeOptionName)
+         foreach ($optpage_data['vals'] as $groupNumber => $optionGroup)
+            foreach ($optionGroup as $optionNumber => $optionItem)
+               if (isset($optionItem['name']) && $optionItem['name'] == $removeOptionName)
+                  unset($optpage_data['vals'][$groupNumber][$optionNumber]);
+
+}
+
+
+
 ?>
